@@ -101,17 +101,8 @@ def download_image(post_id, output_folder=".", name_prefix=None, add_tags=True,
         image_tags_obj.close()
     
     print("    Done downloading! Location: {}".format(image_path))
+    return image_path
 
-
-
-
-
-
-
-
-
-
-    
     
     
 def parse_args(args):
@@ -122,37 +113,12 @@ def parse_args(args):
     return parser.parse_args(args)
 
 def main(args):
-    """Wrapper allowing :func:`fib` to be called with string arguments in a CLI fashion
-
-    Instead of returning the value from :func:`fib`, it prints the result to the
-    ``stdout`` in a nicely formatted message.
-
-    Args:
-      args (List[str]): command line parameters as list of strings
-          (for example  ``["--verbose", "42"]``).
-    """
     args = parse_args(args)
     
     download_image(args.post_id)
 
-
 def run():
-    """Calls :func:`main` passing the CLI arguments extracted from :obj:`sys.argv`
-
-    This function can be used as entry point to create console scripts with setuptools.
-    """
     main(sys.argv[1:])
 
-
 if __name__ == "__main__":
-    # ^  This is a guard statement that will prevent the following code from
-    #    being executed in the case someone imports this file instead of
-    #    executing it as a script.
-    #    https://docs.python.org/3/library/__main__.html
-
-    # After installing your project with pip, users can also run your Python
-    # modules as scripts via the ``-m`` flag, as defined in PEP 338::
-    #
-    #     python -m e621_dl.skeleton 42
-    #
     run()
\ No newline at end of file
